@@ -1007,7 +1007,8 @@ void do_commandline(int argc, char *argv[])
 			/* see if file exists */
 			if (check_interval == 0 && is_cmd == 0 && is_stdin == 0 && is_sock == 0 && retry == 0 && stat64(dummy, &buf) == -1)
 			{
-				error_exit(__FILE__, __PRETTY_FUNCTION__, __LINE__, "Error opening file %s.\n", dummy);
+				fprintf(stderr, "Error opening file %s.\n", dummy);
+				exit(EXIT_FAILURE);
 			}
 
 			/* init. struct. for this file */
